## Metrics

```{eval-rst}
.. module:: scanpy.metrics
```

```{eval-rst}
.. currentmodule:: scanpy
```

Collections of useful measurements for evaluating results.

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   metrics.confusion_matrix
   metrics.gearys_c
   metrics.morans_i

```
